@@ -14,14 +14,14 @@ var bodyParser = require("body-parser");
 var fs = require("fs");
 var path = require("path");
 var manifests = require("./manifests");
-var api = require("../api"), writeError = api.writeError;
+var api = require("../api"), writeError = api.writeError, writeResponse = api.writeResponse;
 
 module.exports.router = function(options) {
-	var contextPath = options.options.configParams["orion.context.path"] || "";
-
+	var fileRoot = options.fileRoot;
+	if (!fileRoot) { throw new Error('options.fileRoot is required'); }
 	return express.Router()
 	.use(bodyParser.json())
-	.get(contextPath + "/file*", getplans);
+	.get(fileRoot + "*", getplans);
 	
 function planJson(type, manifest, planner, wizard, required){
 	return {
@@ -86,7 +86,7 @@ function getplans(req, res){
 		}
 		generatePlansforManifest();
 		var result =  {"Children": children};
-		res.status(200).json(result);
+		writeResponse(200, res, null, result);
 	}).catch(function(err){
 		writeError(404, res, err.message);
 	});
