@@ -18,6 +18,7 @@ var fs = require('fs');
 var args = require('../args');
 var async = require('async');
 var fileUtil = require('../fileUtil');
+var util = require('./util');
 var tasks = require('../tasks');
 var express = require('express');
 var bodyParser = require('body-parser');
@@ -85,6 +86,9 @@ function cloneJSON(base, location, giturl, parents, submodules) {
 		result["PullRequestLocation"] = gitRoot + "/pullRequest" + location;
 	}
 	function isGithubURL(checkUrl){
+		if (checkUrl.indexOf("@") < checkUrl.indexOf(":")){
+ 			checkUrl = "ssh://" + checkUrl;
+ 		}
 		var hostname = url.parse(checkUrl)["hostname"];
 		return hostname === "github.com";
 	}
@@ -92,6 +96,7 @@ function cloneJSON(base, location, giturl, parents, submodules) {
 }
 	
 function getRepoByPath(filePath, workspaceDir) {
+	filePath = util.decodeURIComponent(filePath);
 	while (!fs.existsSync(filePath)) {
 		filePath = path.dirname(filePath);
 		if (filePath.length <= workspaceDir.length) return Promise.reject(new Error("Forbidden"));
@@ -668,6 +673,6 @@ function postClone(req, res) {
 }
 
 function getSignature(repo){
-	return git.Signature.default(repo) || git.Signature.now("unknown","unknown@unknown.com");
+	return git.Signature.default(repo) || git.Signature.now("unknown","unknown@example.com");
 }
 };
