@@ -73,6 +73,15 @@ define([
 		this._sidebarContextMenuNode.id = this.parentId + "ContextMenu"; //$NON-NLS-0$
 
 		this._parentNode.parentNode.insertBefore(this._sidebarContextMenuNode, this._parentNode);
+		if(util.isElectron){
+			this._parentNode.parentNode.classList.add("desktopmode");
+		}else{
+			this.preferences.get("/general/settings").then(function (settings) {
+				if(typeof settings.generalSettings === 'undefined' || settings.generalSettings.desktopSelectionPolicy){
+					this._parentNode.parentNode.classList.add("desktopmode");
+				}
+			}.bind(this));
+		}
 
 		this.contextMenuActionsScope = this._sidebarContextMenuNode.id + "commonNavContextMenu"; //$NON-NLS-0$
 
@@ -93,6 +102,9 @@ define([
 			this.addEventListener("rootChanged", function(evnt) {
 				sidebarNavInputManager.dispatchEvent(evnt);
 			});
+			this.addEventListener("fileDoubleClicked", function(evnt) {
+				sidebarNavInputManager.dispatchEvent(evnt);
+			});
 		}
 		this.selection = new Selection.Selection(this.registry, "commonNavFileSelection"); //$NON-NLS-0$
 		this._selectionListener = function(evnt) {
@@ -113,7 +125,12 @@ define([
 	objects.mixin(CommonNavExplorer.prototype, /** @lends orion.sidebar.CommonNavExplorer.prototype */ {
 		isDesktopSelectionMode: function() {
 			return this.generalPreferences.getPrefs().then(function(genealPrefs) {
-				return genealPrefs.desktopSelectionPolicy;
+				return util.isElectron ? true : genealPrefs.desktopSelectionPolicy;
+			});
+		},
+		isEditorTabsEnabled: function() {
+			return this.generalPreferences.getPrefs().then(function(genealPrefs) {
+				return util.isElectron ? true : genealPrefs.enableEditorTabs;
 			});
 		},
 		onModelCreate: function(evt) {
@@ -238,9 +255,6 @@ define([
 			commandRegistry.registerCommandContribution(fileActionsScope, "eclipse.newFile", 1, "orion.menuBarFileGroup/orion.newContentGroup/orion.new.default"); //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(fileActionsScope, "eclipse.newFolder", 2, "orion.menuBarFileGroup/orion.newContentGroup/orion.new.default", false, null /*, new mCommandRegistry.URLBinding("newFolder", "name")*/ ); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(fileActionsScope, "orion.new.project", 3, "orion.menuBarFileGroup/orion.newContentGroup/orion.new.default"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
-			if (!util.isElectron) {
-				commandRegistry.registerCommandContribution(fileActionsScope, "orion.new.linkProject", 4, "orion.menuBarFileGroup/orion.newContentGroup/orion.new.default"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
-			}
 
 			if (!util.isElectron) {
 				// Import actions
@@ -278,9 +292,6 @@ define([
 			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.newFile", 1, "orion.commonNavContextMenuGroup/orion.newGroup/orion.New"); //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.newFolder", 2, "orion.commonNavContextMenuGroup/orion.newGroup/orion.New", false, null /*, new mCommandRegistry.URLBinding("newFolder", "name")*/ ); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(contextMenuActionsScope, "orion.new.project", 3, "orion.commonNavContextMenuGroup/orion.newGroup/orion.New"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
-			if (!util.isElectron) {
-				commandRegistry.registerCommandContribution(contextMenuActionsScope, "orion.new.linkProject", 4, "orion.commonNavContextMenuGroup/orion.newGroup/orion.New"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
-			}
 
 			// Context Menu edit group actions
 			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.cut", 1, "orion.commonNavContextMenuGroup/orion.editGroup", false); //$NON-NLS-1$ //$NON-NLS-0$
@@ -439,25 +450,22 @@ define([
 	objects.mixin(CommonNavRenderer.prototype, {
 		showFolderLinks: true,
 		oneColumn: true,
-
 		_preventLinkBehavior: function(linkNode) {
 			linkNode.addEventListener("click", function(evt) {
 				this.explorer.isDesktopSelectionMode().then(function(desktopMode) {
-					if (_DEBUG) {
-						var byWho = evt.detail === 3 ? "simulation" : "user";
-						console.log("single click triggered by " + byWho);
-						console.log(evt);
-					}
-					if (desktopMode && (evt.shiftKey || evt.ctrlKey || evt.metaKey) && evt.detail !== 3) {
-						if (_DEBUG) {
-							console.log("single click prevented");
-						}
-						evt.preventDefault();
-					}
+					if(desktopMode){
+ 						evt.preventDefault();
+ 					}
 				});
 			}.bind(this));
 			linkNode.addEventListener("dblclick", function(evt) {
-				this.explorer.handleLinkDoubleClick(linkNode, evt);
+				this.explorer.isDesktopSelectionMode().then(function(desktopMode) {
+					if(desktopMode){
+						evt.preventDefault();
+					}else{
+						this.explorer.handleLinkDoubleClick(linkNode, evt);
+					}
+				});
 			}.bind(this));
 		},
 		createFolderNode: function(folder) {
